import os


class QueryExecutor:
	def __init__(self, ):
		### Always Runs in Quiet Mode
		### For information about logs, specify
		##  in the log file.

		## query instruction build
		## stores last query executed, this is also used in runQuery and callQuery
		self.query = ''

		## show in json format
		self.json = False

		## show in html format we can use only one format at a time
		self.html = False

		## number of processes
		self.processes = 1

		## directory for extracted files
		## default value as text (no flags needed for this)
		self.output = 'text'

		## maximum bytes per output file
		self.bytes = 1000000

		## output file compression using bzip
		self.compress = False

		## preserve links or not
		self.links = False

		## preserve section or not
		self.sections = False

		## preserve list or not
		self.lists = False

		## accepted namespaces in links comma separated
		self.namespaces = ''

		## use or create file containing templates
		self.templates = ''

		## do not expand templates
		self.do_not_expand_templates = False

		## Minimum expanded text length required to write document
		self.min_text_length = 0

		## Include or exclude specific categories from the dataset.
		self.path_of_category_file = ''

		## Remove pages from output that contain disabmiguation markup
		self.filter_disambig_pages = False

		## comma separated list of tags that will be dropped, keeping their content
		self.ignored_tags = ''

		## comma separated list of elements that will be removed from the article text
		self.discard_elements = ''

		## Preserve tables in the output article text
		self.keep_tables = False

		## will save log information in this file
		self.log_file = ''

		## generate file from this plain text by appending dummy tags
		## Because the wikiExtractor works only with those tags
		self.text = ''


	## sets OutputFile Directory Name (used in query building stage)
	def setOutputFileDirectoryName(self, outputDirectory = 'text'):
		self.output = outputDirectory

	## getter function for output file directory
	def getOutputFileDirectoryName(self):
		return self.output

	#setter function
	## flips json and html
	def setJson(self):
		self.json = True
		self.html = False

	#setter function
	## flips json and html
	def sethtml(self):
		self.html = True
		self.json = False


	#setter function
	def setNumberOfProcesses(self, numOfProcesses):
		self.processes = numOfProcesses

	## getter function
	def getNumberOfProcesses(self, numOfProcesses):
		return self.numOfProcesses

	#setter function
	def setNumberOfBytes(self, numOfBytes):
		self.bytes = numOfBytes

	## getter function
	def getNumberOfBytes(self):
		return self.bytes

	#setter function
	def setCompress(self, compressValue):
		self.compress = compressValue

	## getter function
	def getCompressValue(self):
		return self.compress

	#setter function
	def setPreserveLinks(self, preserveValue):
		self.links = preserveValue

	## getter function
	def getPreserveValue(self):
		return self.links

	#setter function
	def setPreserveSections(self, preserveValue):
		self.sections = preserveValue

	## getter function
	def getPreserveSections(self):
		return self.sections

	#setter function
	def setPreserveLists(self, preserveValue):
		self.lists = preserveValue

	## getter function
	def getPreserveLists(self):
		return self.lists

	#setter function
	def setNamespaces(self, ns_list_comma_Separated):
		self.namespaces = ns_list_comma_Separated

	## getter function
	def getNamespaces(self):
		return self.namespaces

	#setter function
	def setTemplates(self, template):
		self.templates = template

	## getter function
	def getTemplates(self):
		return self.templates

	#setter function
	def setMinTextLength(self, min_length):
		self.min_text_length = min_length

	## getter function
	def getMinTextLength(self):
		return self.min_text_length

	#setter function
	def setPathOfCategoryFile(self, file_path):
		self.path_of_category_file = file_path

	## getter function
	def getPathOfCategoryFile(self):
		return self.path_of_category_file

	#setter function
	def setDisambiguationPages(self, setValue):
		self.filter_disambig_pages = setValue

	## getter function
	def getDisambiguationPages(self):
		return self.filter_disambig_pages

	#setter function
	def setIgnoredTagsCommaSeparated(self, comma_separated_tags):
		self.ignored_tags  = comma_separated_tags

	## getter function
	def getIgnoredTagsCommaSeparated(self):
		return self.ignored_tags

	#setter function
	def setDiscardElementsCommaSeparated(self, comma_separated_elements):
		self.discard_elements = comma_separated_elements

	## getter function
	def getDiscardElementsCommaSeparated(self):
		return self.discard_elements

	#setter function
	def setKeepTables(self, keepValue):
		self.keep_tables = keepValue

	## getter function
	def getKeepTables(self):
		return self.keep_tables

	#setter function
	def setLogFileName(self, log_file_name):
		self.log_file = log_file_name

	## getter function
	def getLogFileName(self):
		return self.log_file

	#setter function
	def setDoNotExpandTemplates(self, do_not_expand_templates_value):
		self.do_not_expand_templates = do_not_expand_templates_value

	## getter function
	def getDoNotExpandTemplates(self):
		return self.do_not_expand_templates

	## write in file method
	## intermediate method (you don't need to do it)
	def writeInFile(self, text_value):
		with open('input.xml', 'w') as file:
			file.write(text_value)

	## set text value
	## appends prefix and suffix to text and sets them to
	## the internal variable for further processing
	def setTextValue(self, text_value):

		prefix = """<page>
    <id></id>
    
      <text xml:space="preserve" bytes="1182"> """

		suffix = """</text>
     
  </page> """

		self.text = prefix + text_value + suffix
		self.writeInFile(self.text)


	## gives text value 
	def getTextValue(self):
		return self.text





	## querybuilder method
	## used to build query using presetted descriptors
	## Note: queries always run in --silent mode
	def buildQuery(self):
		cmd = 'python WikiExtractor.py input.xml '# --processes 4 --links --output lol --quiet'

		if(self.json):
			cmd += '--json '
		if(self.html):
			cmd += '--html '

		cmd += '--output ' + self.output + ' '

		cmd += '--processes ' + str(self.processes) + ' '

		if(self.bytes != 1000000):
			cmd += '--bytes ' + str(self.bytes) + ' '

		if(self.compress):
			cmd += '--compress '

		if(self.links):
			cmd += '--links '

		if(self.sections):
			cmd += '--sections '

		if(self.lists):
			cmd += '--lists '

		if(self.namespaces != ''):
			cmd += '--namespaces ' + str(self.namespaces) + ' '

		if(self.templates != ''):
			cmd += '--templates ' + str(self.templates) + ' '

		if(self.do_not_expand_templates):
			cmd += '--no-templates '

		if(self.path_of_category_file != ''):
			cmd += '--filter_category '

		if(self.filter_disambig_pages):
			cmd += '--filter_disambig_pages '

		if(self.ignored_tags != ''):
			cmd += '--ignored_tags ' + str(self.ignored_tags)

		if(self.discard_elements != ''):
			cmd += '--discard_elements ' + str(self.discard_elements) + ' '

		if(self.keep_tables):
			cmd += '--keep_tables '

		if(self.log_file != ''):
			cmd += '--log_file ' + str(self.log_file) + ' '


		cmd += '--quiet'

		self.query = cmd

		#print(cmd)
		#os.system(cmd)

	## callquery method
	## uses system call to run the query command
	def callQuery(self):
		os.system(self.query)

	## queryrunner method
	## builds the query using query text and then runs it
	def runQuery(self):
		self.buildQuery()
		self.callQuery()

	## returns the result in pure text form
	## result is coming from file from self.output/AA/wiki_00 file
	## wiki_00 is generated using wikiExtractor
	def result(self):
		final_output = ''
		file_path = self.output + "/AA/wiki_00"
		with open(file_path) as file:
			final_output = file.read()
			return final_output


##############################################################################################

                                             ### Testing ###
'''
input_text = """
==Impact==
[[Image:DCP 7760.JPG|thumb|right|Tornado damage near a forested area]]
The tornado took a path through [[Rockland County, New York|Rockland]], [[Westchester County, New York|Westchester]], and [[Fairfield County, Connecticut|Fairfield]] counties, downing or uprooting thousands of trees and damaging several structures, including significant structural damage to the California Closest Warehouse. Six minor injuries were also reported. In all, the tornado inflicted $12.1&amp;nbsp;million (2006&amp;nbsp;[[United States Dollar|USD]]; $12.9&amp;nbsp;million 2008 USD) in damage.&lt;ref name="MSSum"/&gt;

Minor damage was reported in Rockland County. One dock and one boat were damaged by the tornado.&lt;ref name="MSSum"/&gt; After crossing the [[Hudson River]], the tornado entered Westchester County, where the worst of the damage took place. It struck the town of [[Sleepy Hollow, New York|Sleepy Hollow]], damaging roofs and tearing the siding off numerous homes and businesses.&lt;ref name="MSSum"/&gt; A 10&amp;nbsp;foot (3&amp;nbsp;m) tall stained-glass window in the St. Teresa of Avila Church was shattered.&lt;ref name="USAT"/&gt; Afterwards, the town of [[Pocantico Hills, New York|Pocantico Hills]] was struck as the tornado intensified to F2 intensity. Several trees were uprooted and two barns were destroyed. The California Closet Warehouse suffered severe structural damage; two concrete walls were destroyed.&lt;ref name="MSSum"/&gt; An interior staircase, which employees used as a shelter, collapsed causing four injuries. Concrete blocks from the building were blown about, some of which struck cars in a nearby parking lot.&lt;ref name="USAT"/&gt; A nearby [[Comfort Inn]] had part of its roof torn off.&lt;ref name="WESH"&gt;{{cite web| date=2006-7-13|author=Associated Press| title=Tornado Rips Through Suburban New York| publisher=[[Internet Broadcasting|Internet Broadcasting Systems, Inc]]| accessdate=2008-11-30|url=http://www.wesh.com/news/9510358/detail.html}}&lt;/ref&gt; After a [[tornado warning]] was issued, a school near the warehouse was evacuated.&lt;ref name="NYTimes"&gt;{{cite news| author=Lisa W. Foderaro| date=2006-07-13| title=Tornado in Westchester Tosses Around Trees and Damages Property| work=[[The New York Times]]| accessdate=2008-11-30|url=http://www.nytimes.com/2006/07/13/nyregion/13weather.html?pagewanted=print}}&lt;/ref&gt; 

[[File:Westchester Tornado damage1.JPG|thumb|left|An area where numerous trees were knocked down, the white tubes support saplings being grown to re-populate the affected area.]]
As the tornado crossed [[New York State Route 9A]], it picked up a state trooper car and flipped it several times before it fell to the ground; the officer inside suffered only minor injuries.&lt;ref name="USAT"/&gt; Moving towards the east-northeast, the tornado struck the towns of [[Mount Pleasant, New York|Mount Pleasant]] and [[Hawthorne, New York|Hawthorne]], damaging numerous trees and causing minor structural damage.&lt;ref name="MSSum"/&gt; Damage along the [[Saw Mill River Parkway]] prompted officials to shut down a section of the highway near Mount Pleasant.&lt;ref name="CNN"&gt;{{cite news| author= Rose Arce | date=2006-07-13| title=Tornado hits north of Manhattan, Winds damage store, close highway; no serious injuries reported| publisher=[[CNN|Cable News Network]]| accessdate=2008-11-30|url=http://www.cnn.com/2006/WEATHER/07/12/ny.tornado/index.html
}}&lt;/ref&gt;  Trees fell on streets and railroad tracks, halting [[Metro-North Railroad]] service and creating major traffic delays.&lt;ref name="NYTimes"/&gt; After passing by the [[Kensico Reservoir]] in [[Valhalla, New York|Valhalla]], the tornado crossed into [[Connecticut]],&lt;ref name="MSSum"/&gt; where it knocked down numerous power lines, cutting power to about 10,000 residences in the county.&lt;ref name="USAT"/&gt; In all, six people sustained minor injuries and damages amounted to $10.1&amp;nbsp;million (2006 USD).&lt;ref name="Tornado2"/&gt;

The weakening tornado ended its duration in Fairfield County, Connecticut in the town of [[Greenwich, Connecticut|Greenwich]]. Thousands of trees were either uprooted or snapped along the tornado's {{convert|2|mi|km|abbr=on}} path through the state. Minor damage was inflicted upon several structures.&lt;ref name="MSSum"/&gt; The tornado left 1,700 residences in Greenwich without power and blocked six roads. Most of the damage was concentrated to the northwestern corner of the town.&lt;ref name="NYTimes2"&gt;{{cite news| author=Avi Salzman and Anahad O'Connor| date=2006-07-16| title=The Week; Rare Tornado Snaps Trees and Power Lines| publisher=The New York Times| accessdate=2008-12-01|url=http://query.nytimes.com/gst/fullpage.html?res=9F04E2D91F30F935A25754C0A9609C8B63}}&lt;/ref&gt; Damages in the state totaled to  $2&amp;nbsp;million (2006 USD).&lt;ref name="Tornado3"/&gt;

==External links==
*[http://wcbstv.com/video/?id=89570@wcbs.dayport.com Doppler Radar image of the tornadic supercell nearing Tarrytown]
*[http://www.youtube.com/watch?v=_fLZLrZAB0M Video of the tornado damage in Westchester]
*[http://wcbstv.com/topstories/Tornado.Tornado.Warning.2.236314.html WCBS article and video of damage/press reports of the tornado]

{{featured article}}
[[Category:F2 tornadoes]]
[[Category:New York tornadoes]]
[[Category:Connecticut tornadoes]]
[[Category:Tornadoes of 2006]]
[[Category:2006 in the United States]]


"""

qe = QueryExecutor()
qe.setOutputFileDirectoryName('lol')
#qe.sethtml()
qe.setNumberOfProcesses(5)
qe.setNumberOfBytes(2000000000)
qe.setTextValue(input_text)
#print(qe.getTextValue())
#qe.setCompress(True)
#qe.setPreserveLinks(True)
qe.runQuery()
print(qe.result())
'''



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Dec 11 21:29:07 2018

@author: descentis
"""

import xml.etree.cElementTree as ET
import textwrap
import html
import os.path
from datetime import datetime
import glob
from subprocess import call
import errno
import os
from internetarchive import download

class qaConverter(object):
    
    def __init__(self):
        self.random = 'just to check'
        print(self.random)
    
    @staticmethod
    def getPostType(name):
        # To get an iterable
        n1 = name.split('/')
        postFile = n1[0]+'/Posts.xml'
        context_post = ET.iterparse(postFile, events=("start", "end"))
        # turning it into an iterator
        context_post = iter(context_post)
        
        # get the root element
        event_posts, root_posts = next(context_post)
        
        postType = {}
        for event, elem in context_post:
            if event == "end" and elem.tag == "row":
                li = []
                if(elem.attrib.get('ParentId')!=None):
                    
                    li.append(elem.attrib['PostTypeId'])
                    li.append(elem.attrib['ParentId'])
                    postType[elem.attrib['Id']] = li
                else:
                    li.append(elem.attrib['PostTypeId'])
                    postType[elem.attrib['Id']] = li
           
                elem.clear()     
                root_posts.clear()
        
        return postType    
    
    @staticmethod
    def make_path(path):
        try:
            os.makedirs(path)
        except OSError as exception:
            if exception.errno != errno.EEXIST:
                raise    

    @staticmethod
    def indent(elem, level=0):
        i = "\n" + level*"  "
        if len(elem):
            if not elem.text or not elem.text.strip():
                elem.text = i + "  "
            if not elem.tail or not elem.tail.strip():
                elem.tail = i
            for elem in elem:
                qaConverter.indent(elem, level+1)
            if not elem.tail or not elem.tail.strip():
                elem.tail = i
        else:
            if level and (not elem.tail or not elem.tail.strip()):
                elem.tail = i
    
    @staticmethod
    def tag_remover(body):
        for i in body:
            if(i=='<'):
                body = body.replace(i,"")
            if(i=='>'):
                body = body.replace(i,", ")
        return body
    
    
    @staticmethod
    def writeHistoryData(*args, **kwargs):
        elem = kwargs['elem']
        post_id = kwargs['post_id']
        instanceId = kwargs['instanceId']
        HistoryType = kwargs['HistoryType']
        postType = kwargs['postType']
        val = kwargs['val']
        name = kwargs['name']
        filePath = name+'/'
        if(val==1 and postType[0]!='2'):
            filePath = filePath+"Post"+str(post_id)+".knolml"
            
            with open(filePath,"w",encoding='utf-8') as myFile:
                myFile.write("<?xml version='1.0' encoding='utf-8'?>\n")
                myFile.write("<KnolML>\n") 
                myFile.write("\t<KnowledgeData "+"Type="+'"'+"QA/text"+'"'+" Id= "+'"'+str(post_id)+'"'+">\n")
                t = '\t'
                f2 = 0
                if(postType[0]!='2'):
                    Instance = t+t+"<Instance Id= "+'"'+str(instanceId)+'"'+" "+"InstanceType= "+'"Revision/Question" '+"RevisionId= "+ '"'+str(elem.attrib['RevisionGUID'])+'"'+">\n"
                    myFile.write(Instance)
                    f2 = 1
                elif(postType[0]=='2'):
                    Instance = t+t+"<Instance Id= "+'"'+str(instanceId)+'"'+" "+"OriginalId= "+'"'+str(post_id)+'"'+" "+"InstanceType= "+'"Revision/Answer" '+"RevisionId= "+ '"'+str(elem.attrib['RevisionGUID'])+'"'+">\n"                
                    myFile.write(Instance)
                    f2=1
    
                
                
                if(f2==1):
        
                    '''
                    Timestamp information
                    '''
                
                    qaConverter.__write_timestamp(myFile, elem)
        
        
                    '''
                    Contributors information
                    '''
                    
                    
                    Contributors = t+t+t+"<Contributors>\n"
                    myFile.write(Contributors)
                    if(elem.attrib.get("UserId") != None):
                        Contributors =t+t+t+t+"<OwnerUserId>"+elem.attrib['UserId']+"</OwnerUserId>\n"
                        myFile.write(Contributors)
                    Contributors = t+t+t+"</Contributors>\n"
                    myFile.write(Contributors)


                    '''
                    PostHistory might have a comment associated with each entry.
                    I have added that section as editDetails
                    '''
        
                    Edit = t+t+t+"<EditDetails>\n"
                    myFile.write(Edit)
                    
                    if(HistoryType.get(int(elem.attrib['PostHistoryTypeId']))!=None):
                        EditType = t+t+t+t+"<EditType>"+HistoryType[int(elem.attrib['PostHistoryTypeId'])]+"</EditType>\n"
                    else:
                        EditType = t+t+t+t+"<EditType>Unknown</EditType>\n"
                    myFile.write(EditType)
        
                    if(elem.attrib.get('Comment')!=None):
                        text_body = textwrap.indent(text=elem.attrib['Comment'], prefix=t+t+t+t)
                        text_body = html.escape(text_body)
                        Body_text = text_body+"\n"
                        EditType = t+t+t+t+"<EditComment>"+Body_text+"</EditComment>\n"
                        myFile.write(EditType)
                    Edit = t+t+t+"</EditDetails>\n"
                    myFile.write(Edit)
                    
        
                    '''
                    Writing the body/text part
                    '''
                    if(elem.attrib.get('Text')!=None):        
                        Body = t+t+t+"<Body>\n"
                        myFile.write(Body)
                        text_field = t+t+t+t+"<Text Type= "+'"'+"text"+'"'+" Bytes="+'"'+str(len(elem.attrib['Text']))+'">\n'
                        myFile.write(text_field)
                        if(elem.attrib['PostHistoryTypeId']=="3" or elem.attrib['PostHistoryTypeId']=="6"):            
                            body_text = elem.attrib['Text']
                            body_text = qaConverter.tag_remover(body_text)
                            text_body = textwrap.indent(text=body_text, prefix=t+t+t+t+t)
                            text_body = html.escape(text_body)
                        else:
                            text_body = textwrap.indent(text=elem.attrib['Text'], prefix=t+t+t+t+t)
                            text_body = html.escape(text_body)
                        Body_text = text_body+"\n"
                        myFile.write(Body_text)
                        text_field = t+t+t+t+"</Text>\n"
                        myFile.write(text_field)        
                        Body = t+t+t+"</Body>\n"
                        myFile.write(Body)
        

                    
                    Instance = t+t+"</Instance>\n"
                    myFile.write(Instance)
                     
                    
        
        else:
            f = 0
            if(postType[0]!='2'):
                filePath = filePath+"Post"+str(post_id)+".knolml"
                f = 1
            elif(postType[0]=='2'):
                
                filePath = filePath+"Post"+str(postType[1])+".knolml"
                f = 1
    
            
            if(f==1):
                with open(filePath,"a",encoding='utf-8') as myFile:
                    t = '\t'
                    if(postType[0]=='1'):
                        Instance = t+t+"<Instance Id= "+'"'+str(instanceId)+'"'+" "+"InstanceType= "+'"Revision/Question" '+"RevisionId= "+ '"'+str(elem.attrib['RevisionGUID'])+'"'+">\n"
                    else:
                        Instance = t+t+"<Instance Id= "+'"'+str(instanceId)+'"'+" "+"OriginalId= "+'"'+str(post_id)+'"'+" "+"InstanceType= "+'"Revision/Answer" '+"RevisionId= "+ '"'+str(elem.attrib['RevisionGUID'])+'"'+">\n"
                    myFile.write(Instance)
                    
        
        
                    '''
                    Timestamp information
                    '''
                
                    qaConverter.__write_timestamp(myFile, elem)
        
        
                    '''
                    Contributors information
                    '''
                    
                    
    
                    if(elem.attrib.get("UserId") != None):
                        Contributors = t+t+t+"<Contributors>\n"
                        myFile.write(Contributors)
                        Contributors =t+t+t+t+"<OwnerUserId>"+elem.attrib['UserId']+"</OwnerUserId>\n"
                        myFile.write(Contributors)
                        Contributors = t+t+t+"</Contributors>\n"
                        myFile.write(Contributors)
                    
        
                    '''
                    Writing the body/text part
                    '''
                    if(elem.attrib.get('Text')!=None):        
                        Body = t+t+t+"<Body>\n"
                        myFile.write(Body)
                        text_field = t+t+t+t+"<Text Type= "+'"'+"text"+'"'+" Bytes="+'"'+str(len(elem.attrib['Text']))+'">\n'
                        myFile.write(text_field)
                        if(elem.attrib['PostHistoryTypeId']=="3" or elem.attrib['PostHistoryTypeId']=="6"):            
                            body_text = elem.attrib['Text']
                            body_text = qaConverter.tag_remover(body_text)
                            text_body = textwrap.indent(text=body_text, prefix=t+t+t+t+t)
                            text_body = html.escape(text_body)
                        else:
                            text_body = textwrap.indent(text=elem.attrib['Text'], prefix=t+t+t+t+t)
                            text_body = html.escape(text_body)
                        Body_text = text_body+"\n"
                        myFile.write(Body_text)
                        text_field = t+t+t+t+"</Text>\n"
                        myFile.write(text_field)        
                        Body = t+t+t+"</Body>\n"
                        myFile.write(Body)
        
                    '''
                    PostHistory might have a comment associated with each entry.
                    I have added that section as editDetails
                    '''
        
                    Edit = t+t+t+"<EditDetails>\n"
                    myFile.write(Edit)
                    
                    if(HistoryType.get(int(elem.attrib['PostHistoryTypeId']))!=None):
                        EditType = t+t+t+t+"<EditType>"+HistoryType[int(elem.attrib['PostHistoryTypeId'])]+"</EditType>\n"
                    else:
                        EditType = t+t+t+t+"<EditType>Unknown</EditType>\n"
                    myFile.write(EditType)
        
                    if(elem.attrib.get('Comment')!=None):
                        text_body = textwrap.indent(text=elem.attrib['Comment'], prefix=t+t+t+t+t)
                        text_body = html.escape(text_body)
                        Body_text = text_body+"\n"
                        EditType = t+t+t+t+"<EditComment>\n"
                        myFile.write(EditType)
                        myFile.write(Body_text)
                        EditType = t+t+t+t+"</EditComment>\n"
                        myFile.write(EditType)
                    Edit = t+t+t+"</EditDetails>\n"
                    myFile.write(Edit)        
    
                    Instance = t+t+"</Instance>\n"
                    myFile.write(Instance)
    
    
    @staticmethod
    def postHistoryConversion(name):
    
        # To get an iterable
        n1 = name.split('/')
        postHistoryFile = n1[0]+'/PostHistory.xml'
        context_postHistory = ET.iterparse(postHistoryFile, events=("start", "end"))
        # turning it into an iterator
        context_postHistory = iter(context_postHistory)
        
        # get the root element
        event_posts, root_posts = next(context_postHistory)
    
        # Dictionary of postHistoryType
        HistoryType = {1:'Initial Title',2:'Initial Body',3:'Initial Tags',4:'Edit Title',5:'Edit Body',6:'Edit Tags',7:'Rollback Title',8:'Rollback Body',
                       9:'Rollback Tags',10:'Post Closed',11:'Post Reopened',12:'Post Deleted',13:'Post Undeleted',14:'Post Locked',15:'Post Unlocked',
                       16:'Community Owned',17:'Post Migrated',18:'Question Merged',19:'Question Protected',20:'Question Unprotected',21:'Post Disassociated',
                       22:'Question Unmerged'}
        
        postIdBuffer = {}
        postType = qaConverter.getPostType(name)
        
        instanceId = 1
        for event, elem in context_postHistory:
            if event == "end" and elem.tag == "row":
                post_id = elem.attrib['PostId']
    
                if(postType[post_id][0]=='1'):
                    if(postIdBuffer.get(post_id)==None):
                        postIdBuffer[post_id] = 1
                        # elem,post_id,instanceId,HistoryType,postType,val,name
                        qaConverter.writeHistoryData(elem=elem, post_id=post_id, instanceId=postIdBuffer[post_id], HistoryType=HistoryType, postType=postType[post_id], val=1, name=name)
                    else:
                        postIdBuffer[post_id]+=1
                        qaConverter.writeHistoryData(elem=elem, post_id=post_id, instanceId=postIdBuffer[post_id], HistoryType=HistoryType, postType=postType[post_id], val=2, name=name)
                    
                    instanceId+=1
                elif(postType[post_id][0]=='2'):
                    if(postIdBuffer.get(post_id)==None):
                        if(postIdBuffer.get(postType[post_id][1])!=None):
                            postIdBuffer[postType[post_id][1]] += 1
                            qaConverter.writeHistoryData(elem=elem,post_id=post_id,instanceId=postIdBuffer[postType[post_id][1]],HistoryType=HistoryType,postType=postType[post_id],val=1,name=name)
                        
                    else:
                        if(postIdBuffer.get(postType[post_id][1])!=None):
                            postIdBuffer[postType[post_id][1]]+=1
                            qaConverter.writeHistoryData(elem=elem,post_id=post_id,instanceId=postIdBuffer[postType[post_id][1]],HistoryType=HistoryType,postType=postType[post_id],val=2,name=name)
                    instanceId+=1
                    
                else:
                    if(postIdBuffer.get(post_id)==None):
                        postIdBuffer[post_id] = 1
                        qaConverter.writeHistoryData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],HistoryType=HistoryType,postType=postType[post_id],val=1,name=name)
                    else:
                        postIdBuffer[post_id]+=1
                        qaConverter.writeHistoryData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],HistoryType=HistoryType,postType=postType[post_id],val=2,name=name)
                    
                    instanceId+=1                    

                elem.clear()
                root_posts.clear()
        

        '''
        file_list = glob.glob(name+"/*.knolml")
        for file_path in file_list:
            if(os.path.isfile(file_path)):
                with open(file_path,"a",encoding='utf-8') as myFile:
                    myFile.write("\t</KnowledgeData>\n")
                    myFile.write("</KnolML>\n")           
        
        '''
        return postType
        
    @staticmethod
    def write_body_rep(elem, myFile):
        '''
        Contributors information
        '''
        
        t = '\t'
        Contributors = t+t+t+"<Contributors>\n"
        myFile.write(Contributors)
        if(elem.attrib.get("OwnerUserId") != None):
            Contributors =t+t+t+t+"<OwnerUserId>"+elem.attrib['OwnerUserId']+"</OwnerUserId>\n"
            myFile.write(Contributors)

        if(elem.attrib.get("LastEditorUserId") != None):
            Contributors =t+t+t+t+"<LastEditorUserId>"+elem.attrib['LastEditorUserId']+"</LastEditorUserId>\n"
            myFile.write(Contributors)
        Contributors = t+t+t+"</Contributors>\n"
        myFile.write(Contributors)


        '''
        PostHistory might have a comment associated with each entry.
        I have added that section as editDetails
        

        Edit = t+t+t+"<EditDetails>\n"
        myFile.write(Edit)
        
        if(HistoryType.get(int(elem.attrib['PostHistoryTypeId']))!=None):
            EditType = t+t+t+t+"<EditType>"+HistoryType[int(elem.attrib['PostHistoryTypeId'])]+"</EditType>\n"
        else:
            EditType = t+t+t+t+"<EditType>Unknown</EditType>\n"
        myFile.write(EditType)

        if(elem.attrib.get('Comment')!=None):
            text_body = textwrap.indent(text=elem.attrib['Comment'], prefix=t+t+t+t)
            text_body = html.escape(text_body)
            Body_text = text_body+"\n"
            EditType = t+t+t+t+"<EditComment>"+Body_text+"</EditComment>\n"
            myFile.write(EditType)
        Edit = t+t+t+"</EditDetails>\n"
        myFile.write(Edit)
        '''
        

        '''
        Writing the body/text part
        '''
        if(elem.attrib.get('Body')!=None):        
            Body = t+t+t+"<Body>\n"
            myFile.write(Body)
            text_field = t+t+t+t+"<Text Type= "+'"'+"text"+'"'+" Bytes="+'"'+str(len(elem.attrib['Body']))+'">\n'
            myFile.write(text_field)

            body_text = elem.attrib['Body']
            #body_text = self.tag_remover(body_text)
            text_body = html.escape(body_text)
            text_body = textwrap.indent(text=text_body, prefix=t+t+t+t+t)
            

            Body_text = text_body+"\n"
            myFile.write(Body_text)
            text_field = t+t+t+t+"</Text>\n"
            myFile.write(text_field)        
            Body = t+t+t+"</Body>\n"
            myFile.write(Body)

        
        if(elem.attrib.get('Tags')!=None):
            Tags_element = t+t+t+"<Tags>"+html.escape(elem.attrib['Tags'])+"</Tags>\n"
            
            myFile.write(Tags_element)
        
        Reputation_tag = t+t+t+"<Credit> \n"
        myFile.write(Reputation_tag)
        if(elem.attrib.get("Score") != None):
            score = t+t+t+t+"<Score>"+elem.attrib['Score']+"</Score>\n"
            myFile.write(score)
        if(elem.attrib.get("ViewCount") != None):
            ViewCount = t+t+t+t+"<ViewCount>"+elem.attrib['ViewCount']+"</ViewCount>\n"
            myFile.write(ViewCount)
        if(elem.attrib.get("AnswerCount") != None):        
            AnswerCount = t+t+t+t+"<AnswerCount>"+elem.attrib['AnswerCount']+"</AnswerCount>\n"
            myFile.write(AnswerCount)
        if(elem.attrib.get("CommentCount") != None):
            CommentCount = t+t+t+t+"<CommentCount>"+elem.attrib['CommentCount']+"</CommentCount>\n"
            myFile.write(CommentCount)
    
        if(elem.attrib.get("FavouriteCount") != None):
            FavouriteCount = t+t+t+t+"<FavouriteCount>"+elem.attrib['FavouriteCount']+"</FavouriteCount>\n"
            myFile.write(FavouriteCount)
    
        Reputation_tag = t+t+t+"</Credit> \n"
        myFile.write(Reputation_tag)        

        
        Instance = t+t+"</Instance>\n"
        myFile.write(Instance)


    '''
    Writing the data for posts
    '''
    @staticmethod
    def __write_timestamp(myFile, elem):
        t = '\t'
        '''
        Timestamp information
        '''
    
        TimeStamp = t+t+t+"<TimeStamp>\n "
        myFile.write(TimeStamp)
        if(elem.attrib.get("CreationDate") != None):
            CreationDate = t+t+t+t+"<CreationDate>"+elem.attrib['CreationDate']+"</CreationDate> \n"
            myFile.write(CreationDate)
        if(elem.attrib.get("LastEditDate") != None):
            LastEditDate = t+t+t+t+"<LastEditDate>"+elem.attrib['LastEditDate']+"</LastEditDate> \n"
            myFile.write(LastEditDate)
        if(elem.attrib.get("LastActivityDate") != None):
            LastActivityDate = t+t+t+t+"<LastActivityDate>"+elem.attrib['LastActivityDate']+"</LastActivityDate> \n"
            myFile.write(LastActivityDate)
        if(elem.attrib.get("CommunityOwnedDate") != None):
            CommunityOwnedDate = t+t+t+t+"<CommunityOwnedDate>"+elem.attrib['CommunityOwnedDate']+"</CommunityOwnedDate> \n"
            myFile.write(CommunityOwnedDate)
        if(elem.attrib.get("ClosedDate") != None):
            ClosedDate = t+t+t+t+"<ClosedDate>"+elem.attrib['ClosedDate']+"</ClosedDate> \n"
            myFile.write(ClosedDate)
        TimeStamp = t+t+t+"</TimeStamp>\n "
        myFile.write(TimeStamp)
        
    @staticmethod
    def writePostData(*args, **kwargs):
        # elem,post_id,instanceId,postType,val,name
        elem = kwargs['elem']
        post_id = kwargs['post_id']
        instanceId = kwargs['instanceId']
        postType = kwargs['postType']
        val = kwargs['val']
        name = kwargs['name']
        filePath = name+'/'
        if(val==1 and postType[0]!='2'):
            filePath = filePath+"Post"+str(post_id)+".knolml"
            
            with open(filePath,"w",encoding='utf-8') as myFile:
                t = '\t'
                myFile.write("<?xml version='1.0' encoding='utf-8'?>\n")
                myFile.write("<KnolML>\n") 
                myFile.write("\t<KnowledgeData "+"Type="+'"'+"QA/text"+'"'+" Id= "+'"'+str(post_id)+'"'+">\n")
                if(elem.attrib.get('Title')!=None):
                    myFile.write(t+t+"<Title>"+html.escape(elem.attrib['Title'])+"</Title>\n")
                
                f2 = 0
                if(postType[0]!='2'):
                    Instance = t+t+"<Instance Id= "+'"'+str(instanceId)+'"'+" "+"InstanceType= "+'"Question"'+">\n"
                    myFile.write(Instance)
                    f2 = 1
                elif(postType[0]=='2'):
                    Instance = t+t+"<Instance Id= "+'"'+str(instanceId)+'"'+" "+"OriginalId= "+'"'+str(post_id)+'"'+" "+"InstanceType= "+'"Answer"'+">\n"                
                    myFile.write(Instance)
                    f2=1
    
                
                
                if(f2==1):
        
                    qaConverter.__write_timestamp(myFile, elem)
        
                    
                    qaConverter.write_body_rep(elem,myFile)
                    
        
        else:
            f = 0
            if(postType[0]!='2'):
                filePath = filePath+"Post"+str(post_id)+".knolml"
                f = 1
            elif(postType[0]=='2'):
                
                filePath = filePath+"Post"+str(postType[1])+".knolml"
                f = 1
    
            
            if(f==1):
                with open(filePath,"a",encoding='utf-8') as myFile:
                    t = '\t'
                    if(postType[0]=='1'):
                        Instance = t+t+"<Instance Id= "+'"'+str(instanceId)+'"'+" "+"InstanceType= "+'"Question"'+">\n"
                    else:
                        Instance = t+t+"<Instance Id= "+'"'+str(instanceId)+'"'+" "+"OriginalId= "+'"'+str(post_id)+'"'+" "+"InstanceType= "+'"Answer"'+">\n"
                    myFile.write(Instance)
                    
        
        
                    '''
                    Timestamp information
                    '''
                
                    qaConverter.__write_timestamp(myFile, elem)
        
                    qaConverter.write_body_rep(elem,myFile)




    '''
    This function converts the Post.xml file into KML
    '''
    
    @staticmethod
    def postConversion(name):
        
        # To get an iterable
        n1 = name.split('/')
        postFile = n1[0]+'/Posts.xml'
        context_post = ET.iterparse(postFile, events=("start", "end"))
        # turning it into an iterator
        context_post = iter(context_post)
        
        # get the root element
        event_posts, root_posts = next(context_post)
        
        postIdBuffer = {}
        #postType = getPostType()
        
        instanceId = 1
        for event, elem in context_post:
            if event == "end" and elem.tag == "row":
                post_id = elem.attrib['Id']
                
                if(elem.attrib['PostTypeId']=='1'):
                    postType = [elem.attrib['PostTypeId']]
                    if(postIdBuffer.get(post_id)==None):
                        postIdBuffer[post_id] = 1
                        #elem,post_id,instanceId,postType,val,name
                        qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],postType=postType,val=1,name=name)
                    else:
                        
                        postIdBuffer[post_id]+=1
                        qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],postType=postType,val=2,name=name)
                    
                    instanceId+=1
                elif(elem.attrib['PostTypeId']=='2'):
                    postType = [elem.attrib['PostTypeId'],elem.attrib['ParentId']]
                    if(postIdBuffer.get(post_id)==None):
                        if(postIdBuffer.get(postType[1])!=None):
                            postIdBuffer[postType[1]] += 1
                            qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[postType[1]],postType=postType,val=1,name=name)
                        
                    else:
                        if(postIdBuffer.get(postType[1])!=None):
                            postIdBuffer[postType[1]] += 1
                            qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[postType[1]],postType=postType,val=2,name=name)
                    instanceId+=1
                    
                else:
                    postType = [elem.attrib['PostTypeId']]
                    if(postIdBuffer.get(post_id)==None):
                        postIdBuffer[post_id] = 1
                        qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],postType=postType,val=1,name=name)
                    else:
                        
                        postIdBuffer[post_id]+=1
                        qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],postType=postType,val=2,name=name)
                    
                    instanceId+=1
                    
                    
                elem.clear()
                root_posts.clear()
        
        '''
        file_list = glob.glob(name+"/*.knolml")
        for file_path in file_list:
            if(os.path.isfile(file_path)):
                with open(file_path,"a",encoding='utf-8') as myFile:
                    myFile.write("</KnolML>\n") 
        '''
        return postType        

    @staticmethod
    def commentsConversion(name,p):
        if(p==0):
            postType = qaConverter.postHistoryConversion(name)
            #self.postConversion(name)
        else:
            postType = qaConverter.getPostType(name)
            qaConverter.postConversion(name)
            

        # To get an iterable
        n1 = name.split('/')
        commentFile = n1[0]+'/Comments.xml'
        context_comments = ET.iterparse(commentFile, events=("start", "end"))
        # turning it into an iterator
        context_comments = iter(context_comments)
        
        # get the root element
        event_posts, root_posts = next(context_comments)
        
        date_format = "%Y-%m-%dT%H:%M:%S.%f"
        for event,elem in context_comments:
            if event == "end" and elem.tag == "row":
                post_id = elem.attrib['PostId']
                post_id_list = postType[post_id]
                if(len(post_id_list)==2):   #checking whether it is a question or answer. If it is an answer, we need to get the parent ID.
                    post_id = post_id_list[1]
                El_id = '"'+elem.attrib['PostId']+'"' #This is to mark the answers
                
                file_path = name+"/Post"+str(post_id)+".knolml" #creating the path for KMNL file
                
                #if(post_id=='3'):
                #print(El_id)
                '''
                if(count==1):
                    break
                count+=1
                '''
                commentDate = elem.attrib['CreationDate']
                
                instance_list = []
                parentId = ''
                if(os.path.exists(file_path)):  #If KMNL file has already been created then read that file
                    
                    dict_answers = {}
                    with open(file_path) as file:
                        for sent in file:
                            if('<Instance' in sent):
                                if('OriginalId' in sent):
                                    sent = sent.split(' ')
                                    #print(sent[4],post_id)
                                    dict_answers[sent[4]] = sent[4]
    
                                    if(dict_answers.get(El_id)!=None):
                                        
                                        parentId = dict_answers[El_id]
                                        '''
                                        if(post_id=='22'):
                                            print(parentId)
                                        '''
                                    sent = " ".join(sent)
                                else:
                                    if(dict_answers.get(El_id)==None):
                                        parentId = '"1"'
                                    
    
                                    
                                #print(parentId)
                            instance_list.append(sent)
    
                    '''
                    if(post_id=='22'):
                        print(dict_answers)
                        print(El_id,parentId)
                    '''
                    
                                    
                    
                    
                    open(file_path, "w").close()
        
    
                comment_index = 0
                index_append_list = 0
                flag = 0
                
                for sent in instance_list:
                    if(flag==1): #This returns that a hit has been found where the comment should be appended 
                        break
                    if("<CreationDate>" in sent):                    
                        post_date = sent.replace('<CreationDate>','')
                        post_date = post_date.replace('</CreationDate>','')
                        post_date = post_date.replace('\t','')
                        post_date = post_date.replace('\n','')
                        post_date = post_date.replace(' ','')
                        post_date = datetime.strptime(post_date, date_format)
                        comDate = datetime.strptime(commentDate, date_format)
                        
                        '''
                        This part finds the index where this comment should be put
                        '''
                        if(comDate<post_date):                        
                            for new_sent in range(comment_index,0,-1):
                                if('<Instance' in instance_list[new_sent]):
                                    index_append_list = new_sent
                                    
                                    flag = 1
                                    break
    
                        
                    comment_index+=1
                
                if(index_append_list==0):
                    index_append_list = len(instance_list)+1
                
                
                '''
                This part adds the comment to its respective place in the list
                '''
                t = '\t'
                Instance = t+t+"<Instance Id= "+"zzz"+" "+"ParentId= "+parentId+" InstanceType="+'"'+"Comments"+'" >\n'
                instance_list.insert(index_append_list,Instance)
                index_append_list+=1
                TimeStamp = t+t+t+"<TimeStamp>\n "
                instance_list.insert(index_append_list,TimeStamp)
                index_append_list+=1
                if(elem.attrib.get("CreationDate") != None):
                    CreationDate = t+t+t+t+"<CreationDate>"+elem.attrib['CreationDate']+"</CreationDate> \n"
                    #myFile.write(CreationDate)
                    instance_list.insert(index_append_list,CreationDate)
                    index_append_list+=1
                TimeStamp = t+t+t+"</TimeStamp>\n "
                #myFile.write(TimeStamp)
                instance_list.insert(index_append_list,TimeStamp)
                index_append_list+=1
                
                contributors = t+t+t+"<Contributors>\n "
                instance_list.insert(index_append_list,contributors)
                index_append_list+=1
                
                if(elem.attrib.get('UserId')!=None):
                    ownerUserId = t+t+t+t+"<OwnerUserId>"+elem.attrib['UserId']+"</OwnerUserId> \n"
                    instance_list.insert(index_append_list,ownerUserId)
                    index_append_list+=1
                else:
                    ownerUserId = t+t+t+t+"<OwnerUserId>"+str(0)+"</OwnerUserId> \n"
                    instance_list.insert(index_append_list,ownerUserId)
                    index_append_list+=1
                    
                contributors = t+t+t+"</Contributors>\n "
                instance_list.insert(index_append_list,contributors)
                index_append_list+=1
                    
                if(elem.attrib.get('Text')!=None):        
                    Body = t+t+t+"<Body>\n"
                    instance_list.insert(index_append_list,Body)
                    index_append_list+=1
                    text_field = t+t+t+t+"<Text Type= "+'"'+"text"+'"'+" Bytes="+'"'+str(len(elem.attrib['Text']))+'">\n'
                    instance_list.insert(index_append_list,text_field)
                    index_append_list+=1
        
                    text_body = textwrap.indent(text=elem.attrib['Text'], prefix=t+t+t+t+t)
                    text_body = html.escape(text_body)
                    Body_text = text_body+"\n"
                    instance_list.insert(index_append_list,Body_text)
                    index_append_list+=1
                    text_field = t+t+t+t+"</Text>\n"
                    instance_list.insert(index_append_list,text_field)
                    index_append_list+=1
                    Body = t+t+t+"</Body>\n"
                    instance_list.insert(index_append_list,Body)
                    index_append_list+=1

                Reputation_tag = t+t+t+"<Credit> \n"
                instance_list.insert(index_append_list,Reputation_tag)
                index_append_list+=1
                if(elem.attrib.get("Score") != None):
                    score = t+t+t+t+"<Score>"+elem.attrib['Score']+"</Score>\n"
                    instance_list.insert(index_append_list,score)
                    index_append_list+=1
                    
            
                Reputation_tag = t+t+t+"</Credit> \n"
                instance_list.insert(index_append_list,Reputation_tag)
                index_append_list+=1                       

                
                Instance = t+t+"</Instance>\n"
                instance_list.insert(index_append_list,Instance)
                
                '''
                Writing everything to the file
                '''
                open(file_path, "w").close()
                
                '''
                instanceId = 1
                dict_answers = {'1':'1'}
                
                for myLine in instance_list:
                    if('<Instance Id' in myLine):
                        myLine = myLine.split(' ')
                        myLine[2] = '"'+str(instanceId)+'"'
                        myLine = " ".join(myLine)
                        
                        if(myLine[3] == 'OriginalId='):   
                            if(dict_answers.get(myLine[4])==None):
                                dict_answers[myLine[4]] = str(instanceId)
                        
                        instanceId+=1
                '''
                
                
                instanceId = 1
                '''            
                if(post_id == '22'):
                    print(dict_answers)            
                '''
                
                dict_answers = {'"1"':'"1"'}
                #print(dict_answers)
                with open(file_path,'a') as myFile:
                    
                    for myLine in instance_list:
                        '''
                        if(post_id=='22'):
                            if('<Instance Id' in myLine):
                                print(myLine)
                        '''
                        if('<Instance Id' in myLine):
    
                            myLine = myLine.split(' ')
                            myLine[2] = '"'+str(instanceId)+'"'
                            #myLine[2] = '"'+str(instanceId)+'"'
                            
                            
                            if(myLine[3] == 'OriginalId='):   
                                if(dict_answers.get(myLine[4])==None):
                                    dict_answers[myLine[4]] = '"'+str(instanceId)+'"'
    
                            
                            
                            if(myLine[3]=='ParentId='):
                                
                                #print(file_path)
                                #print(myLine[0],myLine[1],myLine[2],myLine[3],myLine[4],myLine[5],myLine[6])
                                
                                '''
                                if(post_id == '22'):
                                    print(myLine[5])
                                '''
                                #print(file_path)
                                #print(myLine)
                                
                                if((dict_answers.get(myLine[4])!=None)):
                                    '''
                                    if(post_id == '21'):
                                        print(myLine[4])
                                    '''
                                    myLine[4] = dict_answers[myLine[4]]
                                    
                            
                            
                            myLine = " ".join(myLine)
                            instanceId+=1
                            
                            '''
                            if(post_id == '22'):
                                print(dict_answers)
                            '''
                        myFile.write(myLine)    
    
                elem.clear()
                root_posts.clear()

        file_list = glob.glob(name+"/*.knolml")
        for file_path in file_list:
            if(os.path.isfile(file_path)):
                with open(file_path,"a",encoding='utf-8') as myFile:
                    myFile.write("\t</KnowledgeData>\n")
                    myFile.write("</KnolML>\n")                 
                
    
    @staticmethod            
    def convert(*args, **kwargs):
        name = kwargs['name']
        name = name.lower()
        if(kwargs.get('download')!=None):             
            down = kwargs['download']
            if(down):

                
                with open('stackExchangeList.txt','r') as myFile:
                    for line in myFile:
                        if(name in line):
                            siteName = line[:-1]
                print("Downloading the "+name+" Stack Exchange data dump")
                download('stackexchange', verbose=True, glob_pattern=siteName)
                qaConverter.make_path(name)
                call(["7z","x",'stackexchange/'+siteName,'-o'+name])
                
                '''
                calling the KML converter for Stack_exchange
                '''
                
                if(kwargs.get('posthistory')!=None):
                    ph = kwargs['posthistory']
                    if(ph):
                        print("Converting PostHistory of "+name+" Stack Exchange into knolml")
                        qaConverter.make_path(name+"/PostHistory")
                        namePh = name+"/PostHistory"
                        qaConverter.commentsConversion(namePh,0)
                        print("PostHistory conversion completed for "+name+" Stack Exchange")
                if(kwargs.get('post')!=None):
                    p = kwargs['post']
                    if(p):
                        print("Converting Posts of "+name+" Stack Exchange into knolml")
                        qaConverter.make_path(name+"/Posts")
                        nameP = name+"/Posts"
                        qaConverter.commentsConversion(nameP,1)
                        print("Posts conversion completed for "+name+" Stack Exchange")
                
            else:
                '''
                calling the KML converter for Stack_exchange
                '''
                with open('stackExchangeList.txt','r') as myFile:
                    for line in myFile:
                        if(name in line):
                            siteName = line[:-1]

                call(["7z","x",'stackexchange/'+siteName,'-o'+name])
                
                if(kwargs.get('posthistory')!=None):
                    ph = kwargs['posthistory']
                    if(ph):
                        print("Converting PostHistory of "+name+" Stack Exchange into knolml")
                        qaConverter.make_path(name+"/PostHistory")
                        namePh = name+"/PostHistory"
                        qaConverter.commentsConversion(namePh,0)
                        print("PostHistory conversion completed for "+name+" Stack Exchange")

                if(kwargs.get('post')!=None):
                    p = kwargs['post']
                    if(p):
                        print("Converting Posts of "+name+" Stack Exchange into knolml")
                        qaConverter.make_path(name+"/Posts")
                        nameP = name+"/Posts"
                        qaConverter.commentsConversion(nameP,1)
                        print("Posts conversion completed for "+name+" Stack Exchange")
                


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Dec 31 14:38:53 2019

@author: descentis
"""

import unittest
from kdap.wikiextract.wikiExtract import wikiExtract
class TestWikiExtract(unittest.TestCase):
    
    def setUp(self): 
        pass
    
    def test_category(self):
        '''
        testing the category method
        '''
        d = {'Left-wing advocacy groups in France': [{'pageid': 7932537,
   'ns': 0,
   'title': 'Comité de vigilance des intellectuels antifascistes'},
  {'pageid': 8417221, 'ns': 0, 'title': 'ADFE-Français du Monde'},
  {'pageid': 33092539,
   'ns': 0,
   'title': 'Section des sourds et malentendants socialistes'},
  {'pageid': 2799424, 'ns': 0, 'title': 'SOS Racisme'}],
 'extra#@#category': []}
        we = wikiExtract()
        C = we.get_articles_by_category('Left-wing advocacy groups in France')
        self.assertEqual(C, d)
    
    
    def test_template(self):
        # testing the template method
        t = {'python': [{'pageid': 45459, 'ns': 0, 'title': 'Control flow'},
  {'pageid': 59231, 'ns': 0, 'title': 'Exception handling'},
  {'pageid': 1010628, 'ns': 0, 'title': 'Method overriding'},
  {'pageid': 23655350,
   'ns': 4,
   'title': 'Wikipedia:Bots/Requests for approval/jverlindaBot'},
  {'pageid': 58886025, 'ns': 2, 'title': 'User:Lpwarner/be bold'}]}
        we = wikiExtract()
        C = we.get_articles_by_template('python')
        self.assertEqual(C,t)
        
    def test_author_wiki_edits(self):
        # testing the wiki author edits
        e = [{'name': 'Ak47', 'missing': ''}]
        we = wikiExtract()
        C = we.get_author_wiki_edits(['ak47'])
        self.assertEqual(C, e)
        
if __name__ == '__main__': 
    unittest.main() 